@@ -33,7 +33,7 @@
 class AI_Newton : public AI_Base
 {
 public:
-   QString whoami() { return QString ("Newton"); } // IDW test.
+   QString whoami() override { return QString ("Newton"); } // IDW test.
 
    /**
    * The Newton AI constructor.
@@ -60,7 +60,7 @@ public:
    */
    int assessCube (const int index,         const Player player,
                    const int neighbors [4], const Player owners[],
-                   const int values[],      const int    maxValues[]) const;
+                   const int values[],      const int    maxValues[]) const override;
 };
 
 #endif // AI_NEWTON_H
